@@ -3,7 +3,7 @@
 -------------------------------------------------
    File Name：     simple_request
    Description :
-   Author :        艾登科技 Asdil
+   Author :        Asdil
    date：          2020/10/29
 -------------------------------------------------
    Change Activity:
@@ -34,3 +34,20 @@ def post(url, data, header=None):
                         headers=header)
     ret = ret.json()
     return ret
+
+
+def get(url, headers={}, data={}):
+    """get方法用于get数据
+    Parameters
+    ----------
+    url : str
+        url地址
+    data : dict
+        post data数据
+    headers : dict
+        post header 数据
+    Returns
+    ----------
+    """
+    response = requests.request("GET", url, headers=headers, data=data)
+    return json.loads(response.text)
\ No newline at end of file
